#include <iostream>
//#include <cmath>

#include <QtGui>
#include "mainwindow.h"



MainWindow::MainWindow(QWidget *parent)
    : QMainWindow(parent), ui(new Ui::MainWindow)
{
    ui->setupUi(this);


    dataCnt=0;
    ui->plotter->initPlotter();

    QTimer *timer = new  QTimer(this);
    connect(timer, SIGNAL(timeout()), this, SLOT(readEP2()));
    connect(timer, SIGNAL(timeout()), ui->plotter, SLOT(calculateLines()));
    connect(timer, SIGNAL(timeout()), ui->plotter, SLOT(update()));

    timer->start(1000);

    for(int i=0;i<RowCount;++i) {
      for(int j=0;j<ColumnCount;++j) {
        ui->tableWidget->setItem(i,j,new QTableWidgetItem(tr("")));
      }      
    }
 }

void MainWindow::on_timeButton_clicked()
{
  quint8 timebuff[8] = {0x00,0x30,0x12,0x02,0x10,0x08,0x10,0x10};
  // Sekunden,Minuten,Stunden,Wochentag,Tag,Monat,Jahr,Kontrollbyte
  // Das Kontrollbyte muss 0x10 sein, damit der 1Hz Ausgang aktiviert wird
  timebuff[0]= dt.time().second()/10*16+dt.time().second()%10+1;
  if (timebuff[0] == 60) timebuff[0] = 0;
  timebuff[1]= dt.time().minute()/10*16+dt.time().minute()%10;
  timebuff[2]= dt.time().hour()/10*16+dt.time().hour()%10;
  timebuff[3]= dt.date().dayOfWeek();
  timebuff[4]= dt.date().day()/10*16+dt.date().day()%10;
  timebuff[5]= dt.date().month()/10*16+dt.date().month()%10;
  timebuff[6]= (dt.date().year()-2000)/10*16+(dt.date().year()-2000)%10;
  send_to_EP1(timebuff,0x08);
}

void MainWindow::readEP2()
{
  quint8 buffer[EP2_FIFO_Size];
  QString time,time_s,date,co2,temp,hum,temp2,hum2;
  int co2_d,temp_d,hum_d,time_d;

  dt = QDateTime::currentDateTime();
  //cout << dt.date().day() << dt.date().month() << dt.date().year();
  if (ui->dateTimeEdit->hasFocus())
    dt=ui->dateTimeEdit->dateTime();
  else ui->dateTimeEdit->setDateTime(dt);

  ui->plotter->zoom = ui->zoomspinBox->value()/100.0;

  get_from_EP2(buffer,EP2_FIFO_Size);
  date.append((char*)buffer);
  date = date.mid(8,8);
  time.append((char*)buffer);
  time.resize(8);
  time_s = time;
  time_s = time_s.right(2);
  time_d=time_s.toInt();
  co2.append((char*)buffer);
  co2 = co2.mid(16,4);
  if (co2[0]=='0') co2.remove(0,1);
  co2_d=co2.toInt();
  temp.append((char*)buffer);
  temp = temp.mid(21,5);
  temp2=temp;
  temp2.remove(',');
  temp_d=temp2.toInt();
  hum.append((char*)buffer);
  hum = hum.mid(26,5);
  hum2=hum;
  hum2.remove(',');
  hum_d=hum2.toInt();

  ui->plotter->time_d2 =time_d;


  if (ui->plotter->FlagStop == true) {           // Beachte auch Behandlung der Flags in plotter.ccp (Plotter::draw)
    if (ui->plotter->FlagStart == true) {        // beide wahr: Start erstes mal bzw. nach einem Stop gedrueckt,
      dataCnt=0;                                 //  Tabelle und Zaehler auf null
      for(int i=0;i<RowCount;++i) {
        for(int j=0;j<ColumnCount;++j) {
          ui->tableWidget->setItem(i,j,new QTableWidgetItem(tr("")));
        }
      }
    }                                            // Stop wahr (Start unwahr) nichts tun (Zaehler nicht erhoehen)
  }
  else
    if (ui->plotter->FlagStart == false)        // beide unwahr: Aufzeichnung laeuft
    if (time_d%5 == 0) {
      ui->tableWidget->item(dataCnt,0)->setText(date);
      ui->tableWidget->item(dataCnt,1)->setText(time);
      ui->tableWidget->item(dataCnt,2)->setText(co2);
      ui->tableWidget->item(dataCnt,3)->setText(temp);
      ui->tableWidget->item(dataCnt,4)->setText(hum);

      ui->plotter->co2_d2 =co2_d;
      ui->plotter->temp_d2 = temp_d;
      ui->plotter->hum_d2 = hum_d;
      ui->plotter->date_2 = date;
      ui->plotter->time_2 = time;
      dataCnt++;
      ui->tableWidget->scrollToItem(ui->tableWidget->item(dataCnt,0));

    };


}

bool MainWindow::saveAs()
{
  QFileDialog *mydialog = new QFileDialog;
  QString fileName = mydialog->getSaveFileName(this,
                               tr("Save CSV-File (the suffix is automatically added!"), ".",
                               tr("CSV files (*.csv)"));
  if (fileName.endsWith (".csv", Qt::CaseInsensitive) == false)
        fileName.append (".csv");

  if (fileName.isEmpty())
        return false;
    return writeFile(fileName);
}


bool MainWindow::writeFile(const QString &fileName)
{
  bool cellnotempty;
  QFile file(fileName);
  if (!file.open(QIODevice::WriteOnly)) {
      QMessageBox::warning(this, tr("CO22"),
                           tr("Cannot write file %1:\n%2.")
                           .arg(file.fileName())
                           .arg(file.errorString()));
      return false;
    }

  QTextStream out(&file);
  QChar ch(176); //176 = unicode charecter code for the degree symbol
    out << "Datum" << "\t" << "Zeit" << "\t" << "CO2 [ppm]" << "\t" << "Temperatur [" << ch << "C]" << "\t" << "Luftfeuchtigkeit [%]" << "\n";

    for (int row = 0; row < RowCount; ++row) {
        for (int col = 0; col < ColumnCount; ++col) {
            QString str = ui->tableWidget->item(row,col)->text();
            cellnotempty=(!str.isEmpty());
            if (cellnotempty)
              out << str << "\t";
        }
        if (cellnotempty)
          out << "\n";
      }
    return true;
}

void MainWindow::about()
{
    QMessageBox::about(this, tr("About CO22"),
            tr("<h2>CO22 ""the mobile measurement station"" 1.0</h2>"
               "<p>Copyright &copy; 2010 www.weigu.lu</p>"
               "<p>For help:</p>"
               "<p>1. browse www.weigu.lu/b</p>"
               "<p>2. mail to weigu@weigu.lu<p>"));
}

void MainWindow::print()
{
    ui->plotter->FlagPrint=true;
}

void MainWindow::pdf()
{
    ui->plotter->FlagPdf=true;
}

void MainWindow::png()
{
    ui->plotter->FlagPng=true;
}

void MainWindow::copy()
{
    ui->plotter->FlagClip=true;
}

void MainWindow::on_startButton_clicked()
{
    ui->plotter->FlagStart=true;
}

void MainWindow::on_stopButton_clicked()
{
    ui->plotter->FlagStop=true;
}

MainWindow::~MainWindow()
{
    delete ui;
}



