#include <QtGui>
#include "plotter.h"

Plotter::Plotter(QWidget *parent): QWidget(parent)
{

}

void Plotter::initPlotter(void)

{
  x=0;
  FlagPrint = false;
  FlagPdf = false;
  FlagPng = false;
  FlagStart = false;
  FlagStop = true;
  FlagClip = false;
}

void Plotter::paintEvent(QPaintEvent *)
{
  QImage graph(size(), QImage::Format_ARGB32);
  QPainter graphPainter(&graph);
  graphPainter.setRenderHint(QPainter::Antialiasing, true);

  graphPainter.eraseRect(rect());
  draw(&graphPainter);
  graphPainter.end();

  QPainter widgetPainter(this);
  widgetPainter.drawImage(0,0,graph);
  widgetPainter.end();

  if(FlagPrint==true || FlagPdf==true)
    printGraph(&graph);
  if (FlagPng==true) {
    FlagPng = false;
    QFileDialog *mydialog = new QFileDialog;
    QString fileName = mydialog->getSaveFileName(this,
                             tr("Save PNG-File (the suffix is automatically added!"), ".",
                             tr("PNG files (*.png)"));
    if (fileName.endsWith (".png", Qt::CaseInsensitive) == false)
        fileName.append (".png");
    if (fileName.isEmpty()) fileName="graph.png";
    graph.save(fileName,"PNG");
  }

  if (FlagClip==true) {
    FlagClip = false;

    QClipboard *clip = QApplication::clipboard();
    clip->setImage(graph,QClipboard::Clipboard);
  }
}


void Plotter::printGraph(QImage *graph)
{
  QPrinter printer;
  printer.setOrientation(QPrinter::Landscape);
  printer.setCreator("www.weigu.lu");
  printer.setPaperSize(QPrinter::A4);
  if (FlagPrint==true) {
    FlagPrint = false;
    QPrintDialog printDialog(&printer,this);
    if(printDialog.exec()==QDialog::Accepted) {
      QPainter printgraphPainter(&printer);
      printgraphPainter.drawImage(0,0,*graph);
      printgraphPainter.end();
    }
  }
  if (FlagPdf==true) {
    FlagPdf = false;
    QFileDialog *mydialog = new QFileDialog;
    QString fileName = mydialog->getSaveFileName(this,
                               tr("Save PDF-File (the suffix is automatically added!"), ".",
                               tr("PDF files (*.pdf)"));
    if (fileName.endsWith (".pdf", Qt::CaseInsensitive) == false)
          fileName.append (".pdf");
    if (fileName.isEmpty()) fileName="graph.pdf";
    printer.setOutputFileName(fileName);
    QPainter pdfgraphPainter(&printer);
    pdfgraphPainter.drawImage(0,0,*graph);
    pdfgraphPainter.end();
  }  
}

void Plotter::calculateLines(void)
{
  int co2_p, temp_p, hum_p;

  // Startdatum festlegen
  if (x==0) {
    date_g2=date_2;
    time_g2=time_2;
  }

  co2_p = axisxco2-(co2_d2-360)/4;        // 360 ppm kleinster dargestellter Wert!
  temp_p = axisxtemp-(temp_d2-1700)/10;   // 17.0 °C kleinster dargestellter Wert!
  hum_p = axisxhum-(hum_d2-2500)*3/100;    // 25 % kleinster dargestellter Wert!

  co2points[x].setX(x+axisy+3); //Punktarrays befuellen
  temppoints[x].setX(x+axisy+3);
  humpoints[x].setX(x+axisy+3);
  if (co2_d2 == 0) co2points[x].setY(co2points[x-1].y());
  else co2points[x].setY(co2_p);
  temppoints[x].setY(temp_p);
  humpoints[x].setY(hum_p);
  /*co2points[0].setY(co2points[2].y());  //Korrektur fuer erste Werte
  co2points[1].setY(co2points[2].y());
  temppoints[0].setY(temppoints[2].y());
  temppoints[1].setY(temppoints[2].y());
  humpoints[0].setY(humpoints[2].y());
  humpoints[1].setY(humpoints[2].y());*/

    if (FlagStop == true) {
    if (FlagStart == true) {        // beide wahr: Start erstes mal bzw. nach einem Stop gedrueckt, x-Zaehler auf null
      FlagStart=false;
      FlagStop=false;
      x=0;
    }                               // Stop wahr (Start unwahr) nichts tun (Zaehler nicht erhoehen)
  }
  else {
    if (FlagStart == false)         // beide unwahr: Aufzeichnung laeuft
      if (x<(xsize-axisy-lspan-arrowl) && (time_d2%5==0))  x++;
    else {}//x=0;
      else FlagStart=false;         // Stop unwahr (Start wahr): Start zweites mal gedrueckt,
  }                                 // Ruecksetzen damit Aufzeichnung weiterlaeuft
}




void Plotter::draw(QPainter *graphPainter)
{



  QPolygon arrowco2x,arrowco2y,arrowtempx,arrowtempy,arrowhumx,arrowhumy;
  QBrush brush;
  QPen pen;
  QPixmap weigu(":/images/weigu.png");



  if (FlagPrint || FlagPdf || FlagPng || FlagClip)
    graphPainter->scale(1.0,1.0);
  else
    graphPainter->scale(zoom,zoom);
  if (FlagPrint || FlagPdf) graphPainter->setViewport(0,0,1000,700);
  if (FlagPng || FlagClip) graphPainter->setViewport(0,0,1899,899);

  // Ampelhintergruende zeichnen CO2
  graphPainter->setPen(QPen(Qt::NoPen));
  brush.setStyle(Qt::SolidPattern);
  brush.setColor(lightgreen);
  graphPainter->setBrush(QBrush(brush));
  graphPainter->drawRect(axisy,axisxco2-(co2grlim-360)/4,xsize-axisy-lspan-arrowl-laspan,(co2grlim-360)/4);
  brush.setColor(lightorange);
  graphPainter->setBrush(QBrush(brush));
  graphPainter->drawRect(axisy,axisxco2-(co2orlim-360)/4,xsize-axisy-lspan-arrowl-laspan,(co2orlim-360)/4-(co2grlim-360)/4);
  brush.setColor(lightred);
  graphPainter->setBrush(QBrush(brush));
  graphPainter->drawRect(axisy,axisxco2-(co2redlim-360)/4,xsize-axisy-lspan-arrowl-laspan,(co2redlim-360)/4-(co2orlim-360)/4);
  // Ampelhintergruende zeichnen Temp
  brush.setColor(lightblue);
  graphPainter->setBrush(QBrush(brush));
  graphPainter->drawRect(axisy,axisxtemp-(tempbllim-1700)/10,xsize-axisy-lspan-arrowl-laspan,(tempbllim-1700)/10);
  brush.setColor(lightgreen);
  graphPainter->setBrush(QBrush(brush));
  graphPainter->drawRect(axisy,axisxtemp-(tempgrlim-1700)/10,xsize-axisy-lspan-arrowl-laspan,(tempgrlim-1700)/10-(tempbllim-1700)/10);
  brush.setColor(lightorange);
  graphPainter->setBrush(QBrush(brush));
  graphPainter->drawRect(axisy,axisxtemp-(temporlim-1700)/10,xsize-axisy-lspan-arrowl-laspan,(temporlim-1700)/10-(tempgrlim-1700)/10);
  brush.setColor(lightred);
  graphPainter->setBrush(QBrush(brush));
  graphPainter->drawRect(axisy,axisxtemp-(tempredlim-1700)/10,xsize-axisy-lspan-arrowl-laspan,(tempredlim-1700)/10-(temporlim-1700)/10);
  // Ampelhintergruende zeichnen Hum
  brush.setColor(lightgreen);
  graphPainter->setBrush(QBrush(brush));
  graphPainter->drawRect(axisy,axisxhum-(humgrhlim-2500)*3/100,xsize-axisy-lspan-arrowl-laspan,(humgrhlim-2500)*3/100-(humgrllim-2500)*3/100);
  brush.setColor(lightorange);
  graphPainter->setBrush(QBrush(brush));
  graphPainter->drawRect(axisy,axisxhum-(humorhlim-2500)*3/100,xsize-axisy-lspan-arrowl-laspan,(humorhlim-2500)*3/100-(humgrhlim-2500)*3/100);
  graphPainter->drawRect(axisy,axisxhum-(humorllim-2500)*3/100,xsize-axisy-lspan-arrowl-laspan,(humorllim-2500)*3/100-(humgrllim-2500)*3/100);
  brush.setColor(lightred);
  graphPainter->setBrush(QBrush(brush));
  graphPainter->drawRect(axisy,axisxhum-(humredhlim-2500)*3/100,xsize-axisy-lspan-arrowl-laspan,(humredhlim-2500)*3/100-(humorhlim-2500)*3/100);
  graphPainter->drawRect(axisy,axisxhum-(humredllim-2500)*3/100,xsize-axisy-lspan-arrowl-laspan,(humredllim-2500)*3/100-(humorllim-2500)*3/100);

  // Achsenlinien zeichnen
  graphPainter->setPen(QPen(Qt::black,3));
  graphPainter->drawLine(axisy-aspan,axisxco2,xsize-lspan,axisxco2);  // Horizontal
  graphPainter->drawLine(axisy-aspan,axisxtemp,xsize-lspan,axisxtemp);
  graphPainter->drawLine(axisy-aspan,axisxhum,xsize-lspan,axisxhum);
  graphPainter->drawLine(axisy,tspan,axisy,axisxco2+aspan);           // Vertikal
  graphPainter->drawLine(axisy,axisxco2+aspan+vspan,axisy,axisxtemp+aspan);
  graphPainter->drawLine(axisy,axisxtemp+aspan+vspan,axisy,axisxhum+aspan);

  // Einteilung horizontale Achsen
  graphPainter->setPen(QPen(Qt::darkBlue,1,Qt::SolidLine));                   // Minutenstriche
  for (int j=12;j<1810;j=j+12) {
    graphPainter->drawLine(axisy+j,axisxco2-aspan,axisy+j,axisxco2+aspan);
    graphPainter->drawLine(axisy+j,axisxtemp-aspan,axisy+j,axisxtemp+aspan);
    graphPainter->drawLine(axisy+j,axisxhum-aspan,axisy+j,axisxhum+aspan);
  }
  graphPainter->setPen(QPen(Qt::darkBlue,3,Qt::SolidLine));                   // Viertelstundenstriche
  for (int j=180;j<1810;j=j+180) {
    graphPainter->drawLine(axisy+j,axisxco2-aspan,axisy+j,axisxco2+aspan);
    graphPainter->drawLine(axisy+j,axisxtemp-aspan,axisy+j,axisxtemp+aspan);
    graphPainter->drawLine(axisy+j,axisxhum-aspan,axisy+j,axisxhum+aspan);
  }
  // Viertelstundenlinien
  graphPainter->setPen(QPen(Qt::darkBlue,1,Qt::DashDotLine));                  // Viertelstundenlinien
  for (int j=180;j<1810;j=j+180) {
    graphPainter->drawLine(axisy+j,tspan+arrowl+10,axisy+j,axisxco2);
    graphPainter->drawLine(axisy+j,axisxco2+vspan+arrowl+15,axisy+j,axisxtemp);
    graphPainter->drawLine(axisy+j,axisxtemp+vspan+arrowl+15,axisy+j,axisxhum);
  }
  //Einteilung Vertikal CO2
  graphPainter->setPen(QPen(Qt::darkBlue,1,Qt::SolidLine));                   // Hunderterstriche CO2
  for (int j=axisxco2-10;j>tspan;j=j-25) {
    graphPainter->drawLine(axisy+aspan,j,axisy-aspan,j);
  }
  graphPainter->setPen(QPen(Qt::darkBlue,1,Qt::DashDotLine));                 // Hunderterlinien CO2
  for (int j=axisxco2-10;j>tspan;j=j-25) {
    graphPainter->drawLine(axisy+aspan,j,xsize-lspan-arrowl-laspan,j);
  }
  graphPainter->setPen(QPen(Qt::darkBlue,3,Qt::SolidLine));                   // Fuenfhunderterstriche CO2
  for (int j=axisxco2-35;j>tspan;j=j-125) {
    graphPainter->drawLine(axisy+aspan,j,axisy-aspan,j);
  }
  //Einteilung Vertikal Temp
  graphPainter->setPen(QPen(Qt::darkBlue,1,Qt::SolidLine));                   // Gradstriche Temp
  for (int j=axisxtemp;j>axisxco2+vspan+arrowl;j=j-10) {
    graphPainter->drawLine(axisy+aspan,j,axisy-aspan,j);
  }
  graphPainter->setPen(QPen(Qt::darkBlue,3,Qt::SolidLine));                   // 5 Gradstriche Temp
  for (int j=axisxtemp-30;j>axisxco2+vspan+arrowl;j=j-50) {
    graphPainter->drawLine(axisy+aspan,j,axisy-aspan,j);
  }
  graphPainter->setPen(QPen(Qt::darkBlue,1,Qt::DashDotLine));                 // 5 Gradlinien Temp
  for (int j=axisxtemp-30;j>axisxco2+vspan+arrowl;j=j-50) {
    graphPainter->drawLine(axisy+aspan,j,xsize-lspan-arrowl-laspan,j);
  }
  //Einteilung Vertikal Hum
  graphPainter->setPen(QPen(Qt::darkBlue,1,Qt::SolidLine));                   // 5% Striche Hum
  for (int j=axisxhum;j>axisxtemp+vspan+arrowl;j=j-15) {
    graphPainter->drawLine(axisy+aspan,j,axisy-aspan,j);
  }
  graphPainter->setPen(QPen(Qt::darkBlue,3,Qt::SolidLine));                   // 5 Gradstriche Temp
  for (int j=axisxhum-15;j>axisxtemp+vspan+arrowl;j=j-30) {
    graphPainter->drawLine(axisy+aspan,j,axisy-aspan,j);
  }
  graphPainter->setPen(QPen(Qt::darkBlue,1,Qt::DashDotLine));                 // 5 Gradlinien Temp
  for (int j=axisxhum-15;j>axisxtemp+vspan+arrowl;j=j-30) {
    graphPainter->drawLine(axisy+aspan,j,xsize-lspan-arrowl-laspan,j);
  }

  // Ampellinien CO2
  pen.setColor(0xFFBB00);
  pen.setWidth(2);
  pen.setStyle(Qt::DashDotDotLine);
  graphPainter->setPen(QPen(pen));
  graphPainter->drawLine(axisy+aspan,axisxco2-(co2grlim-360)/4,xsize-lspan-arrowl-laspan,axisxco2-(co2grlim-360)/4);

  graphPainter->setPen(QPen(Qt::red,2,Qt::DashDotLine));
  graphPainter->drawLine(axisy+aspan,axisxco2-(co2orlim-360)/4,xsize-lspan-arrowl-laspan,axisxco2-(co2orlim-360)/4);
  // Ampellinien Temp
  graphPainter->setPen(QPen(Qt::blue,2,Qt::DashDotLine));
  graphPainter->drawLine(axisy+aspan,axisxtemp-(tempbllim-1700)/10,xsize-lspan-arrowl-laspan,axisxtemp-(tempbllim-1700)/10);
  pen.setColor(0xFFBB00);
  pen.setWidth(2);
  pen.setStyle(Qt::DashDotDotLine);
  graphPainter->setPen(QPen(pen));
  graphPainter->drawLine(axisy+aspan,axisxtemp-(tempgrlim-1700)/10,xsize-lspan-arrowl-laspan,axisxtemp-(tempgrlim-1700)/10);
  graphPainter->setPen(QPen(Qt::red,2,Qt::DashDotLine));
  graphPainter->drawLine(axisy+aspan,axisxtemp-(temporlim-1700)/10,xsize-lspan-arrowl-laspan,axisxtemp-(temporlim-1700)/10);
  // Ampellinien Hum
  graphPainter->setPen(QPen(Qt::green,2,Qt::DashDotLine));
  pen.setColor(0xFFBB00);
  pen.setWidth(2);
  pen.setStyle(Qt::DashDotDotLine);
  graphPainter->setPen(QPen(pen));
  graphPainter->drawLine(axisy+aspan,axisxhum-(humgrllim-2500)*3/100,xsize-lspan-arrowl-5,axisxhum-(humgrllim-2500)*3/100);
  graphPainter->drawLine(axisy+aspan,axisxhum-(humgrhlim-2500)*3/100,xsize-lspan-arrowl-5,axisxhum-(humgrhlim-2500)*3/100);
  graphPainter->setPen(QPen(Qt::red,2,Qt::DashDotLine));
  graphPainter->drawLine(axisy+aspan,axisxhum-(humorllim-2500)*3/100,xsize-lspan-arrowl-5,axisxhum-(humorllim-2500)*3/100);
  graphPainter->drawLine(axisy+aspan,axisxhum-(humorhlim-2500)*3/100,xsize-lspan-arrowl-5,axisxhum-(humorhlim-2500)*3/100);



  //Achsenpfeile zeichnen
  graphPainter->setPen(QPen(Qt::black,3));
  graphPainter->setBrush(QBrush(Qt::black));
  arrowco2y << QPoint(axisy,tspan) << QPoint(axisy+arroww,tspan+arrowl) << QPoint(axisy-arroww,tspan+arrowl);
  arrowtempy << QPoint(axisy,axisxco2+aspan+vspan) << QPoint(axisy+arroww,axisxco2+aspan+vspan+arrowl) << QPoint(axisy-arroww,axisxco2+aspan+vspan+arrowl);
  arrowhumy << QPoint(axisy,axisxtemp+aspan+vspan) << QPoint(axisy+arroww,axisxtemp+aspan+vspan+arrowl) << QPoint(axisy-arroww,axisxtemp+aspan+vspan+arrowl);
  arrowco2x << QPoint(xsize-lspan,axisxco2) << QPoint(xsize-lspan-arrowl,axisxco2+arroww) << QPoint(xsize-lspan-arrowl,axisxco2-arroww);
  arrowtempx << QPoint(xsize-lspan,axisxtemp) << QPoint(xsize-lspan-arrowl,axisxtemp+arroww) << QPoint(xsize-lspan-arrowl,axisxtemp-arroww);
  arrowhumx << QPoint(xsize-lspan,axisxhum) << QPoint(xsize-lspan-arrowl,axisxhum+arroww) << QPoint(xsize-lspan-arrowl,axisxhum-arroww);
  graphPainter->drawPolygon(arrowco2y);
  graphPainter->drawPolygon(arrowtempy);
  graphPainter->drawPolygon(arrowhumy);
  graphPainter->drawPolygon(arrowco2x);
  graphPainter->drawPolygon(arrowtempx);
  graphPainter->drawPolygon(arrowhumx);

  //Achsentext (vertikal) schreiben
  graphPainter->setPen(QPen(Qt::black,1));
  font.setPointSize(10);
  graphPainter->setFont(font);
  graphPainter->drawText(19,tspan+axisxco2-10,"360");
  graphPainter->drawText(28,tspan+axisxtemp-10,"17");
  graphPainter->drawText(28,tspan+axisxtemp-10-160,"33");
  graphPainter->drawText(28,tspan+axisxhum-10,"25");
  graphPainter->drawText(28,tspan+axisxhum-10-150,"75");
  font.setPointSize(12);
  graphPainter->setFont(font);
  graphPainter->drawText(18,tspan+axisxco2-10-35,"500");
  graphPainter->drawText(8,tspan+axisxco2-10-160,"1000");
  graphPainter->drawText(8,tspan+axisxco2-10-285,"1500");
  graphPainter->drawText(8,tspan+axisxco2-10-410,"2000");

  graphPainter->drawText(27,tspan+axisxtemp-10-30,"20");
  graphPainter->drawText(27,tspan+axisxtemp-10-80,"25");
  graphPainter->drawText(27,tspan+axisxtemp-10-130,"30");

  graphPainter->drawText(27,tspan+axisxhum-10-15,"30");
  graphPainter->drawText(27,tspan+axisxhum-10-45,"40");
  graphPainter->drawText(27,tspan+axisxhum-10-75,"50");
  graphPainter->drawText(27,tspan+axisxhum-10-105,"60");
  graphPainter->drawText(27,tspan+axisxhum-10-135,"70");




  //Logo zeichnen
  graphPainter->drawPixmap(xsize-140,10,weigu);
  // Datum und Uhrzeit schreiben
  font.setBold(1);
  graphPainter->drawText(xsize/2-160,tspan+10,"Starting date and time: "+date_g2+"  "+time_g2);

  // Achsenbeschriftung

  graphPainter->drawText(axisy+15,tspan+10,"CO2 [ppm]");
  graphPainter->drawText(1840,axisxco2+20,"t [min]");
  QString ch(176);
  QString txt = "Temperature [" + ch + "C]";
  graphPainter->drawText(axisy+15,axisxco2+vspan+20,txt);
  graphPainter->drawText(axisy+15,axisxtemp+vspan+20,"Humidity [%]");
  graphPainter->drawText(1840,axisxco2+20,"t [min]");
  graphPainter->drawText(1840,axisxtemp+20,"t [min]");
  graphPainter->drawText(1840,axisxhum+20,"t [min]");


  //Achsentext (horizontal) schreiben
  graphPainter->drawText(axisy-5,axisxco2+20,"0");
  graphPainter->drawText(axisy-10+180,axisxco2+20,"15");
  graphPainter->drawText(axisy-10+2*180,axisxco2+20,"30");
  graphPainter->drawText(axisy-10+3*180,axisxco2+20,"45");
  graphPainter->drawText(axisy-10+4*180,axisxco2+20,"60 (1h)");
  graphPainter->drawText(axisy-10+5*180,axisxco2+20,"75");
  graphPainter->drawText(axisy-10+6*180,axisxco2+20,"90");
  graphPainter->drawText(axisy-14+7*180,axisxco2+20,"105");
  graphPainter->drawText(axisy-14+8*180,axisxco2+20,"120 (2h)");
  graphPainter->drawText(axisy-14+9*180,axisxco2+20,"135");
  graphPainter->drawText(axisy-5,axisxtemp+20,"0");
  graphPainter->drawText(axisy-10+180,axisxtemp+20,"15");
  graphPainter->drawText(axisy-10+2*180,axisxtemp+20,"30");
  graphPainter->drawText(axisy-10+3*180,axisxtemp+20,"45");
  graphPainter->drawText(axisy-10+4*180,axisxtemp+20,"60 (1h)");
  graphPainter->drawText(axisy-10+5*180,axisxtemp+20,"75");
  graphPainter->drawText(axisy-10+6*180,axisxtemp+20,"90");
  graphPainter->drawText(axisy-14+7*180,axisxtemp+20,"105");
  graphPainter->drawText(axisy-14+8*180,axisxtemp+20,"120 (2h)");
  graphPainter->drawText(axisy-14+9*180,axisxtemp+20,"135");
  graphPainter->drawText(axisy-5,axisxhum+20,"0");
  graphPainter->drawText(axisy-10+180,axisxhum+20,"15");
  graphPainter->drawText(axisy-10+2*180,axisxhum+20,"30");
  graphPainter->drawText(axisy-10+3*180,axisxhum+20,"45");
  graphPainter->drawText(axisy-10+4*180,axisxhum+20,"60 (1h)");
  graphPainter->drawText(axisy-10+5*180,axisxhum+20,"75");
  graphPainter->drawText(axisy-10+6*180,axisxhum+20,"90");
  graphPainter->drawText(axisy-14+7*180,axisxhum+20,"105");
  graphPainter->drawText(axisy-14+8*180,axisxhum+20,"120 (2h)");
  graphPainter->drawText(axisy-14+9*180,axisxhum+20,"135");


  //calculateLines();


/*  co2_p = axisxco2-(co2_d2-360)/4;        // 360 ppm kleinster dargestellter Wert!
  temp_p = axisxtemp-(temp_d2-1700)/10;   // 17.0 °C kleinster dargestellter Wert!
  hum_p = axisxhum-(hum_d2-2500)*3/100;    // 25 % kleinster dargestellter Wert!



  co2points[x].setX(x+axisy+3); //Punktarrays befuellen
  temppoints[x].setX(x+axisy+3);
  humpoints[x].setX(x+axisy+3);
  if (co2_d2 == 0) co2points[x].setY(co2points[x-1].y());
  else co2points[x].setY(co2_p);
  temppoints[x].setY(temp_p);
  humpoints[x].setY(hum_p);/*
  /*co2points[0].setY(co2points[2].y());  //Korrektur fuer erste Werte
  co2points[1].setY(co2points[2].y());
  temppoints[0].setY(temppoints[2].y());
  temppoints[1].setY(temppoints[2].y());
  humpoints[0].setY(humpoints[2].y());
  humpoints[1].setY(humpoints[2].y());*/

  // Polylinien (Daten) zeichnen
  graphPainter->setPen(QPen(Qt::red,3));
  graphPainter->drawPolyline(co2points,x);
  graphPainter->setPen(QPen(Qt::red,3));
  graphPainter->drawPolyline(temppoints,x);
  graphPainter->setPen(QPen(Qt::red,3));
  graphPainter->drawPolyline(humpoints,x);

  /*if (FlagStop == true) {
    if (FlagStart == true) {        // beide wahr: Start erstes mal bzw. nach einem Stop gedrueckt, x-Zaehler auf null
      FlagStart=false;
      FlagStop=false;
      x=0;
    }                               // Stop wahr (Start unwahr) nichts tun (Zaehler nicht erhoehen)
  }
  else {
    if (FlagStart == false)         // beide unwahr: Aufzeichnung laeuft
      if (x<(xsize-axisy-lspan-arrowl) && (time_d2%10==0))  x++;
    else {}//x=0;
      else FlagStart=false;         // Stop unwahr (Start wahr): Start zweites mal gedrueckt,
  }                                 // Ruecksetzen damit Aufzeichnung weiterlaeuft
*/

}



