#include "usb_drv.h"

quint16 timeout = 2000;

struct usb_device *usb_find_device(void)
{
  struct usb_bus *bus;
  struct usb_device *dev;
  usb_init();
  usb_find_busses();
  usb_find_devices();
  for (bus = usb_busses; bus; bus = bus->next)
  {
    for (dev = bus->devices; dev; dev = dev->next)
    {
      if ((dev->descriptor.idVendor == MyUSB_VendorID) && (dev->descriptor.idProduct == MyUSB_ProductID))
        return dev;
    }
  }
  return 0;
}

struct usb_dev_handle *usb_claim_device(void)
{
  struct usb_device *dev;
  struct usb_dev_handle *handle;
  int set_conf_error, claim_int_error;
  dev = usb_find_device();
  if (dev == NULL) cout << "USB device not found!";
  handle = usb_open(dev);
  if (handle == NULL) cout << "USB device handle not found!";
  set_conf_error = usb_set_configuration(handle, 1);
  if ( set_conf_error < 0)
  {
    cout << "Can not set configuration (errorcode = " << set_conf_error << "!)";
    usb_close(handle);
  }
  claim_int_error = usb_claim_interface(handle, 0);
  if ( claim_int_error < 0)
  {
    cout << "Can not claim interface (errorcode = " << claim_int_error << "!)";
    usb_close(handle);
  }
  return handle;
}

void send_to_EP1(quint8 *buff1, quint8 samples)
{
  struct usb_dev_handle *handle;
  quint16 i;

  handle = usb_claim_device();
  i = usb_bulk_write(handle, 0x01, (char*) buff1, samples, timeout);

  usb_release_interface(handle, 0);
  usb_close(handle);
}

void get_from_EP2(quint8 *buff1, quint8 samples)
{
  struct usb_dev_handle *handle;
  quint8 charbuff[EP2_FIFO_Size];
  quint16 i;

  handle = usb_claim_device();
  //Achtung keine Nullbytes schicken!!
  i = usb_bulk_read(handle, 0x82, (char*) charbuff, samples, timeout);
  
  for (int j=0;j<i;j++)
  {
    buff1[j] = charbuff[j];
  }

  usb_release_interface(handle, 0);
  usb_close(handle);
}

